import os, random, pygame
from pygame.locals import *

if not pygame.font: print 'Warning, fonts disabled'
if not pygame.mixer: print 'Warning, sound disabled'

def load_image(name, colorkey=None):
    fullname = name
    try:
        image = pygame.image.load(fullname)
    except pygame.error, message:
        print 'Cannot load image:', fullname
        raise SystemExit, message
    image = image.convert_alpha()
    if colorkey is not None:
        if colorkey is -1:
            colorkey = image.get_at((0,0))
        image.set_colorkey(colorkey, RLEACCEL)
    return image
    
class Tile(pygame.sprite.Sprite):
    tileType = "rock"
    tileImage = None
    tileRect = None

    def __init__(self, t, img):
        pygame.sprite.Sprite.__init__(self)
        self.tileType = t
        self.tileImage = img
        self.tileRect = img.get_rect()

    def clone(self):
        return Tile(self.tileType, self.tileImage)
    

class World:
    orientation = "north"
    depth = 0
    width = 0
    height = 0
    terrain = [] # One-dimensional array, length == depth * width.
                 # Width varies faster.
                 # Each position has an array representing height.
    
    def __init__(self, d, w, h, t = []):
        self.depth = d
        self.width = d
        self.height = h
        if t == []:
            for i in range(d*w):
                self.terrain.append([])
        else:
            for i in range(d*w):
                self.terrain.append(t[i])

    def getPosition(self, x, y):
        return x*self.width + y

    def draw(self, screen):
        #print "Terrain"
        #print self.terrain
        #print "Space 0"
        #print self.terrain[0]
        #print "Height 0"
        #print self.terrain[0][0]
        
        screen.blit(self.terrain[0][0].tileImage, (10, 10))


def generateTerrain(d, w, h, tiles):
    terr = []

    for i in range(d*w):
        tileSpace = []
        for j in range(0, random.randint(1, h)):
            tileSpace.append(random.choice(tiles).clone())
        terr.append(tileSpace)
    return terr


def main():
    pygame.init()
    screen = pygame.display.set_mode( (640, 480) )
    clock = pygame.time.Clock()

    rockTile = Tile('rock', load_image(os.path.join('data', 'Plain Block.png') ))
    grassTile = Tile('grass', load_image(os.path.join('data' , 'Grass Block.png') ))

    world = World(4, 5, 3, generateTerrain(4, 5, 3, [rockTile, grassTile]))
    while 1:          
        screen.fill((60, 60, 90))
        world.draw(screen)
        pygame.display.flip();

        for event in pygame.event.get():
            if event.type == QUIT:
                return
            elif event.type == KEYDOWN and event.key == K_ESCAPE:
                return

        clock.tick(60)
    
if __name__ == '__main__':
    main()

